.. warning:: **This package does everything but what you want, don't use it.**

================================================================================
                                deproulette
================================================================================


Do you ever get tired of knowing what you get? Have you ever felt you needed
to spice up your deployments?

With deproulette, you get what you wish for approximately none of the times.
This imprecision is achieved through "creative" use of the python package
distribution framework.

--------------------------------------------------------------------------------
                                 Usage
--------------------------------------------------------------------------------

Think of one or more packages, no need for unique packages,
but at most 5 packages, then run

.. code-block:: bash

    pip install deproulette

Once this has run, you have probably installed something else than what you
were thinking of. If not: please shoot me an email.

--------------------------------------------------------------------------------
                         How does it work?
--------------------------------------------------------------------------------

To achieve maximum discomfort for its users, deproulette downloads a list of
packages from https://pypi.python.org/simple/, then selects a random package
from that list between ``range(0, randint(2, 6))`` times.

For all the details,
see https://github.com/joar/deproulette/blob/master/setup.py.